angular.module('controllers', [])

.run(function($rootScope, serverService, conf) {
    $rootScope.answers = {};

    if(localStorage.getItem("timestamps") !== null) {
        $rootScope.timestamps = JSON.parse(localStorage.getItem("timestamps"));
    } else {
        $rootScope.timestamps = {}
    }

    document.addEventListener('resume', function() {
        $rootScope.surveyLoading = true;
        delete $rootScope.data;
        delete $rootScope.sponsors;
        serverService.survey(true).then(function(data) {
            $rootScope.data = data;
            $rootScope.surveyLoading = false;
            $rootScope.assetsPath = conf.server[0] + $rootScope.data.assetsPath;
            $rootScope.sponsors = (JSON.parse(data.extra)).sponsor;
        });
    });
})

.controller('RadioCtrl', function($scope, $rootScope, $stateParams, popup, conf, server, $interval, $ionicPopup, popup, serverService, $cordovaGoogleAnalytics) {
    $scope.surveyId = $stateParams.surveyId;
    if (!$rootScope.answers[$scope.surveyId]) {
        $rootScope.answers[$scope.surveyId] = {};
    }


    //$cordovaGoogleAnalytics.trackEvent('cantina', 'viasat');
    $scope.active = 0;
    $interval(function() {
        if ($scope.active >= $rootScope.sponsors.length -1) {
            $scope.active = 0;
        } else {
            $scope.active += 1;
        }
    }, 6000);

    $scope.sponsorClick = function(index) {
        popup.confirm($rootScope.sponsors[index].popupTitle, $rootScope.sponsors[index].popupContent).then(function() {
            //$cordovaGoogleAnalytics.trackEvent('Videos', 'event', 'button', 'click', 'cantina', 1);
            //window.open(conf.server[0] + $rootScope.data.assetsPath + 'cantina.html', '_blank', 'location=yes');
            window.open($rootScope.sponsors[index].url, '_blank');
        });
    }

    $scope.reload = function(refresh) {
        serverService.survey(refresh).then(function(data) {
            $rootScope.data = data;
            $rootScope.surveyLoading = false;
            $scope.$broadcast('scroll.refreshComplete');
            $rootScope.assetsPath = conf.server[0] + $rootScope.data.assetsPath;
            $rootScope.sponsors = (JSON.parse(data.extra)).sponsor;
        })
    }

    if(typeof($rootScope.data) === 'undefined') {
        $rootScope.surveyLoading = true;
        $scope.reload(false);
    } else {
        $rootScope.surveyLoading = false;
    }
})

.controller('DetailCtrl', function($scope, $rootScope, $stateParams, conf, server, $timeout, $state) {
    $scope.surveyId = $stateParams.surveyId;
    $scope.detailId = $stateParams.detailId;

    if ($rootScope.data.surveys[$scope.surveyId].timestamp == $rootScope.timestamps[$scope.surveyId]) {
        $scope.votedOnStart = true;
    }

    $scope.details = $rootScope.data.surveys[$scope.surveyId].groups[0].questions[0].options[$scope.detailId];

    if ($scope.details.img) {
        $scope.imagePath = $rootScope.assetsPath +  $scope.details.img;
    }

    $scope.submit = function() {
        $rootScope.submitLoading = true;
        var d = (new Date()).getTime();

        var packet = {}
        packet[$rootScope.data.surveys[$scope.surveyId].groups[0].questions[0].id] = $scope.details.value;
        packet[$rootScope.data.surveys[$scope.surveyId].groups[0].questions[1].id] = localStorage.getItem("phonenumber");

        server.post(packet).then(function(data) {
            $timeout(function() {
                localStorage.setItem('selection', $scope.detailId);
                $rootScope.answers[$scope.surveyId] = {};

                $rootScope.timestamps[$scope.surveyId] = $rootScope.data.surveys[$scope.surveyId].timestamp;
                localStorage.setItem('timestamps', JSON.stringify($rootScope.timestamps));

                $scope.voted = true;
            }, (new Date()).getTime() - d + 2000);
        }, function() {
            $rootScope.submitLoading = false;
        });
    }
})

.controller('ReportCtrl', function($scope, $rootScope, server, $timeout, conf, serverService) {
    $scope.reportLoading = true;

    $scope.reload = function(refresh) {
        serverService.report(refresh).then(function(data) {
            $scope.reportData = data;

            if ($rootScope.data.surveys[0].timestamp == $rootScope.timestamps[0]) {
                $scope.selection = localStorage.getItem("selection");
            }

            $scope.reportLoading = false;
            $scope.$broadcast('scroll.refreshComplete');
        })
    }

    $scope.reportLoading = true;
    $scope.reload(false);

})

.controller('SettingsCtrl', function($scope, $rootScope, server) {
    $scope.logout = function() {
        server.logout().then(function(data) {
            $rootScope.data = null;
            $rootScope.answers = {};
            redirect.to("login", true);
        }, function(data) {
            popup.error(null, "Logout failed");
        });
    }

    $scope.unregister = function() {
        $cordovaPush.unregister().then(function(result) {
            console.log("unregister success!");
        }, function(err) {
            console.log("unregister failed!");
        });
    }

    $scope.reload = function() {
        server.survey().then(function(data) {
            $rootScope.data = data.data;
            redirect.to("start", null, true);
        }, function(data) {
            services.statusCode(data.status, data.data, true);
        });
    }

    $scope.reset = function() {
        localStorage.removeItem("phonenumber");
        localStorage.removeItem("selection");
        localStorage.removeItem("timestamps");

        $rootScope.timestamps = {}
    }

    $scope.input = {};
    $scope.phonenumber = localStorage.getItem("phonenumber");
    $scope.updateLocalStorage = function(where, what) {
        localStorage.setItem(where, what);
    }
})

.controller('PhonenumberCtrl', function($scope, $state) {
    $scope.input = {};
    $scope.input.phonenumber = "";
    localStorage.setItem("phonenumber", "");

    $scope.submit = function() {
        localStorage.setItem("phonenumber", $scope.input.phonenumber);
        $state.go('tab.radio', {surveyId: 0});
    }
})





.controller('DashCtrl', function($scope) {
})

.controller('FriendsCtrl', function($scope, Friends) {
    $scope.friends = Friends.all();
})

.controller('FriendDetailCtrl', function($scope, $stateParams, Friends) {
    $scope.friend = Friends.get($stateParams.friendId);
})

.controller('AccountCtrl', function($scope) {
});
