angular.module('services', [])

.factory('popup', function($rootScope, $ionicPopup, $q) {
    return {
        error: function(status, data, buttonText) {
            var deferred = $q.defer();

            if (buttonText == null) {
                buttonText = 'OK';
            }

            var alertPopup = $ionicPopup.alert({
                title: 'Error ' + status,
                template: data,
                buttons: [{ text: buttonText }]
            }).then(function() {
                deferred.resolve(null);
            });

            return deferred.promise;
        },
        confirm: function(heading, text) {
            var deferred = $q.defer();

            var alertPopup = $ionicPopup.confirm({
                title: heading,
                template: text
            }).then(function(res) {
                if (res) {
                    deferred.resolve();
                } else {
                    deferred.reject();
                }
            });

            return deferred.promise;
        },
        error0: function(status, text) {

        }
    }
})

.factory('serverService', function($q, server, popup, $timeout) {
    return {
        survey: function(refresh) {
            return survey(refresh);
        },
        report: function(refresh) {
            return report(refresh);
        }
    }

    function survey(refresh) {
        var deferred = $q.defer();

        var d = (new Date()).getTime();
        var tmpData;

        server.survey(refresh).then(function(data) {
            if(typeof data.data.surveys !== 'undefined'){
                tmpData = data.data;
                var timestamps = {}
                timestamps[0] = data.data.timestamp;
            } else {
                popup.error(415, "Server response of wrong format");
            }
        }, function(data) {
            if (data.status == 410) {
                popup.error("", "The server does not support this app anymore, are you sure you have the latest version?", "OK");
            } else {
                popup.error(0, "Could not connect to server", "Retry").then(function() {
                    survey(true);
                });
            }
        }).finally(function(data) {
            if (refresh) {
                $timeout(function() {
                    deferred.resolve(tmpData);

                }, (new Date()).getTime() - d + 1000);
            } else {
                deferred.resolve(tmpData);
            }
        });

        return deferred.promise;
    }

    function report(refresh) {
        var deferred = $q.defer();

        var d = (new Date()).getTime();
        var tmpData;

        server.report(true).then(function(data) {
            if(typeof data.data.surveys !== 'undefined'){
                tmpData = data.data.surveys[0].groups[0].questions[0];
            } else {
                popup.error(415, "Server response of wrong format");
            }

        }, function(data) {
            popup.error(0, "Could not connect to server", "Retry").then(function() {
                report(true);
            });
        }).finally(function(data) {
            if (refresh) {
                $timeout(function() {
                    deferred.resolve(tmpData);

                }, (new Date()).getTime() - d + 1000);
            } else {
                deferred.resolve(tmpData);
            }
        });

        return deferred.promise;
    }

})
